@@ -10,7 +10,7 @@ use vars qw{$err $errstr $drh $sqlite_version};
 use vars qw{%COLLATION};
 
 BEGIN {
-    $VERSION = '1.28_01';
+    $VERSION = '1.28_02';
     @ISA     = 'DynaLoader';
 
     # Initialize errors
@@ -159,6 +159,7 @@ package DBD::SQLite::db;
 sub prepare {
     my $dbh = shift;
     my $sql = shift;
+    $sql = '' unless defined $sql;
 
     my $sth = DBI::_new_sth( $dbh, {
         Statement => $sql,
@@ -536,12 +537,12 @@ END_SQL
     );
 }
 
-
 #======================================================================
 # An internal tied hash package used for %DBD::SQLite::COLLATION, to
 # prevent people from unintentionally overriding globally registered collations.
 
 package DBD::SQLite::_WriteOnceHash;
+
 require Tie::Hash;
 
 our @ISA = qw(Tie::StdHash);
@@ -561,9 +562,6 @@ sub DELETE {
 
 1;
 
-
-
-
 __END__
 
 =pod
@@ -771,9 +769,63 @@ SQLite has a set of "Pragma"s to modifiy its operation or to query
 for its internal data. These are specific to SQLite and are not
 likely to work with other DBD libraries, but you may find some of
 these are quite useful. DBD::SQLite actually sets some (like
-C<foreign_keys> above) for you when you connect to a database.
+C<show_datatypes>) for you when you connect to a database.
 See L<http://www.sqlite.org/pragma.html> for details.
 
+=head2 Transactions
+
+DBI/DBD::SQLite's transactions may be a bit confusing. They behave
+differently according to the status of the C<AutoCommit> flag:
+
+=over 4
+
+=item When the AutoCommit flag is on
+
+You're supposed to always use the auto-commit mode, except you
+explicitly begin a transaction, and when the transaction ended,
+you're supposed to go back to the auto-commit mode. To begin a
+transaction, call C<begin_work> method, or issue a C<BEGIN>
+statement. To end it, call C<commit/rollback> methods, or issue
+the corresponding statements.
+
+  $dbh->{AutoCommit} = 1;
+  
+  $dbh->begin_work; # or $dbh->do('BEGIN TRANSACTION');
+  
+  # $dbh->{AutoCommit} is turned off temporarily during a transaction;
+  
+  $dbh->commit; # or $dbh->do('COMMIT');
+  
+  # $dbh->{AutoCommit} is turned on again;
+
+=item When the AutoCommit flag is off
+
+You're supposed to always use the transactinal mode, until you
+explicitly turn on the AutoCommit flag. You can explicitly issue
+a C<BEGIN> statement (only when an actual transaction has not
+begun yet) but you're not allowed to call C<begin_work> method
+(if you don't issue a C<BEGIN>, it will be issued internally).
+You can commit or roll it back freely. Another transaction will
+automatically begins if you execute another statement.
+
+  $dbh->{AutoCommit} = 0;
+  
+  # $dbh->do('BEGIN TRANSACTION') is not necessary, but possible
+  
+  ...
+  
+  $dbh->commit; # or $dbh->do('COMMIT');
+  
+  # $dbh->{AutoCommit} stays intact;
+  
+  $dbh->{AutoCommit} = 1;  # ends the transactional mode
+
+=back
+
+This C<AutoCommit> mode is independent from the autocommit mode
+of the internal SQLite library, which always begins by a C<BEGIN>
+statement, and ends by a C<COMMIT> or a <ROLLBACK>.
+
 =head2 Performance
 
 SQLite is fast, very fast. Matt processed my 72MB log file with it,
@@ -944,7 +996,6 @@ After this, it could be use from SQL as:
 
   INSERT INTO mytable ( now() );
 
-
 =head3 REGEXP function
 
 SQLite includes syntactic support for an infix operator 'REGEXP', but
@@ -965,7 +1016,6 @@ C<create_function> API described above.
 Note that regexp matching will B<not> use SQLite indices, but will iterate
 over all rows, so it could be quite costly in terms of performance.
 
-
 =head2 $dbh->sqlite_create_collation( $name, $code_ref )
 
 This method manually registers a new function which will be useable in an SQL
@@ -987,7 +1037,6 @@ The driver will check that this is a proper sorting function.
 
 =back
 
-
 =head2 $dbh->sqlite_collation_needed( $code_ref )
 
 This method manually registers a callback function that will
@@ -1004,7 +1053,6 @@ so for most common cases it will be simpler to just
 add your collation sequences in the C<%DBD::SQLite::COLLATION>
 hash (see section L</"COLLATION FUNCTIONS"> below).
 
-
 =head2 $dbh->sqlite_create_aggregate( $name, $argc, $pkg )
 
 This method will register a new aggregate function which can then be used
@@ -1147,7 +1195,6 @@ C<sqlite_rollback_hook> is overridden. A reference to the previous
 callback (if any) is returned.  Registering an C<undef> disables the
 callback.
 
-
 =head2 $dbh->sqlite_update_hook( $code_ref )
 
 This method registers a callback function to be invoked whenever a row
@@ -1184,7 +1231,6 @@ is the unique 64-bit signed integer key of the affected row within that table.
 
 =back
 
-
 =head2 $dbh->sqlite_set_authorizer( $code_ref )
 
 This method registers an authorizer callback to be invoked whenever
@@ -1237,8 +1283,6 @@ top-level SQL code.
 
 =back
 
-
-
 =head2 $dbh->sqlite_backup_from_file( $filename )
 
 This method accesses the SQLite Online Backup API, and will take a backup of
@@ -1260,7 +1304,6 @@ sqlite3 extensions. After the call, you can load extensions like this:
   $sth = $dbh->prepare("select load_extension('libsqlitefunctions.so')")
   or die "Cannot prepare: " . $dbh->errstr();
 
-
 =head1 DRIVER CONSTANTS
 
 A subset of SQLite C constants are made available to Perl,
@@ -1332,7 +1375,6 @@ associated strings.
   FUNCTION                undef           Function Name
   SAVEPOINT               Operation       Savepoint Name
 
-
 =head1 COLLATION FUNCTIONS
 
 =head2 Definition
@@ -1413,7 +1455,6 @@ is to set the parameter at connection time :
       }
   );
 
-
 =head2 Adding user-defined collations
 
 The native SQLite API for adding user-defined collations is
@@ -1440,7 +1481,6 @@ characters :
   my $sql  = "SELECT ... FROM ... ORDER BY ... COLLATE no_accents");
   my $rows = $dbh->selectall_arrayref($sql);
 
-
 The builtin C<perl> or C<perllocale> collations are predefined
 in that same hash.
 
@@ -1460,7 +1500,6 @@ I<requests> for collations. In other words, if you want to change
 the behaviour of a collation within an existing C<$dbh>, you
 need to call the L</create_collation> method directly.
 
-
 =head1 TO DO
 
 The following items remain to be done.
@@ -1470,7 +1509,7 @@ The following items remain to be done.
 We currently use a horridly hacky method to issue and suppress warnings.
 It suffices for now, but just barely.
 
-Migrate all of the warning code to use the recommended DBI warnings.
+Migrate all of the warning code to use the recommended L<DBI> warnings.
 
 =head2 Leak Detection
 
@@ -1486,7 +1525,6 @@ Reading/writing into blobs using C<sqlite2_blob_open> / C<sqlite2_blob_close>.
 
 Support the full API of sqlite3_open_v2 (flags for opening the file).
 
-
 =head1 SUPPORT
 
 Bugs should be reported via the CPAN bug tracker at
@@ -1523,7 +1561,7 @@ Some parts copyright 2008 Francis J. Lacoste.
 
 Some parts copyright 2008 Wolfgang Sourdeau.
 
-Some parts copyright 2008 - 2009 Adam Kennedy.
+Some parts copyright 2008 - 2010 Adam Kennedy.
 
 Some parts derived from L<DBD::SQLite::Amalgamation>
 copyright 2008 Audrey Tang.
